#!/usr/bin/env python

"""LazyDB is a basic wrapper around the Python shelve flatfile dbm module."""

__version__ = "0.1.65"
__author__ = [
    "Mek <michael.karpeles@gmail.com>"
]
__license__ = "public domain"
__contributors__ = "see AUTHORS"
from lazydb import Db, Orm
